@@ -5,11 +5,13 @@ OC.L10N.register(
     "Rename" : "Renomar",
     "Move" : "Mover",
     "Delete" : "Desaniciar",
+    "Search" : "Search",
     "New" : "Nuevu",
     "New folder" : "Carpeta nueva",
     "Grid view" : "Vista de rexella",
     "List view" : "Vista de llista",
     "Select all" : "Esbillar too",
+    "Submit" : "Unviar",
     "Cancel" : "Encaboxar",
     "Recent" : "Reciente",
     "Import" : "Importar",
