@@ -5,22 +5,23 @@ OC.L10N.register(
     "Rename" : "Adı dəyiş",
     "Move" : "Move",
     "Delete" : "Sil",
-    "Save" : "Saxla",
+    "Search" : "Axtarış",
+    "New" : "Yeni",
     "New folder" : "Yeni qovluq",
-    "Create" : "Yarat",
+    "Select all" : "Hamısıı seç",
     "Cancel" : "Dayandır",
     "Import" : "Əlavə et",
     "Export" : "Çıxarış",
-    "URL" : "URL",
+    "Title" : "Başlıq",
+    "Link" : "Link",
     "Tags" : "Işarələr",
     "Notes" : "Qeydlər",
-    "Sharing" : "Paylaşılır",
     "Owner" : "Owner",
+    "Sharing" : "Paylaşılır",
     "Share link" : "Linki yayımla",
     "Copy link" : "linki nüsxələ",
     "Select" : "Select",
-    "Title" : "Başlıq",
-    "Link" : "Link",
-    "Folder" : "Qovluq"
+    "Folder" : "Qovluq",
+    "Save" : "Saxla"
 },
 "nplurals=2; plural=(n != 1);");
