@@ -4,22 +4,22 @@ OC.L10N.register(
     "Rename" : "Preimenuj",
     "Move" : "Move",
     "Delete" : "Obriši",
-    "Save" : "Spremi",
+    "Search" : "Search",
+    "New" : "Novo",
     "New folder" : "Nova fascikla",
-    "Create" : "Ustvari",
+    "Select all" : "Označi sve",
     "Cancel" : "Otkaži",
-    "Public" : "Javno",
     "Import" : "Uvoz",
     "Export" : "Izvezi",
-    "URL" : "Url",
+    "Title" : "Naslov",
+    "Link" : "Veza",
     "Notes" : "Notes",
-    "Sharing" : "Dijeljenje",
     "Owner" : "Vlasnik",
+    "Sharing" : "Dijeljenje",
     "Share link" : "Podijelite vezu",
     "Allow editing" : "Dozvolite izmjenu",
     "Select" : "Select",
-    "Title" : "Naslov",
-    "Link" : "Veza",
-    "Folder" : "Fasikla"
+    "Folder" : "Fasikla",
+    "Save" : "Spremi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
