@@ -28,6 +28,7 @@ OC.L10N.register(
     "No file provided for import" : "No s'ha proporcionat cap fitxer per importar",
     "Unsupported file type for import" : "El tipus de fitxer que voleu importar no és compatible",
     "Bookmarks shared by %s" : "Adreces d'interès compartides per %s",
+    "Recent Bookmarks" : "Adreces d'interès recents",
     "Bookmark" : "Marcadors",
     "Bookmark deleted" : "S'ha suprimit l'adreça d'interès",
     "Bookmark created" : "S’ha creat una adreça d’interès",
@@ -42,6 +43,7 @@ OC.L10N.register(
     "Rename" : "Canvia'n el nom",
     "Move" : "Mou",
     "Delete" : "Suprimeix",
+    "Search" : "Cerca",
     "Select one or more tags" : "Seleccionau una o més etiquetes",
     "New" : "Nou",
     "New bookmark" : "Adreça d'interès nova",
@@ -62,6 +64,7 @@ OC.L10N.register(
     "Enter folder title" : "Escriviu el títol de la carpeta",
     "Shared by {user}" : "Compartit per {user}",
     "Root folder" : "Carpeta d'arrel",
+    "Submit" : "Envia",
     "Cancel" : "Cancel·la",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["S' està movent la carpeta %n i algunes adreces d'interès","S’ estan movent %n carpetes i algunes adreces d'interès"],
     "_Moving %n folder_::_Moving %n folders_" : ["S' està movent la carpeta %n","S’estan movent %n carpetes"],
