@@ -4,12 +4,14 @@ OC.L10N.register(
     "Bookmarks" : "Favoritter",
     "No file provided for import" : "Ingen fil til import",
     "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
+    "Recent Bookmarks" : "Seneste Bokmærker",
     "A Bookmark manager for Nextcloud" : "En app til at administrere bogmærker i Nextcloud",
     "Select bookmark" : "Vælg bogmærke",
     "Details" : "Detaljer",
     "Rename" : "Omdøb",
     "Move" : "Flyt",
     "Delete" : "Slet",
+    "Search" : "Søg",
     "Select one or more tags" : "Vælg et eller flere tags",
     "New" : "Ny",
     "New folder" : "Ny mappe",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Enter a link" : "Indtast et link",
     "Enter folder title" : "Angiv folder navn",
     "Root folder" : "Rodmappe",
+    "Submit" : "Tilføj",
     "Cancel" : "Annullér",
     "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
