@@ -8,11 +8,13 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Search" : "Buscar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Grid view" : "Vista de cuadrícula",
     "List view" : "Vista de lista",
     "Select all" : "Seleccionar todo",
+    "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
     "Add a bookmark" : "Agregar un marcador",
