@@ -4,12 +4,14 @@ OC.L10N.register(
     "Bookmarks" : "Bookmarks",
     "No file provided for import" : "هیچ پرونده ای برای واردکردن ارائه نشده است",
     "Unsupported file type for import" : "این نوع فایل برای افزودن پشتیبانی نمی شود",
+    "Recent Bookmarks" : "نشانک های اخیر",
     "A Bookmark manager for Nextcloud" : "یک مدیر نشانک برای نکست کلود",
     "Select bookmark" : "نشانک را انتخاب کنید",
     "Details" : "جزئیات",
     "Rename" : "تغییرنام",
     "Move" : "انتقال",
     "Delete" : "حذف",
+    "Search" : "جستجو کردن",
     "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
     "New" : "جدید",
     "New folder" : "پوشه جدید",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Enter a link" : "پیوند را وارد کنید",
     "Enter folder title" : "عنوان پوشه را وارد کنید",
     "Root folder" : "پوشهٔ ریشه",
+    "Submit" : "ارسال",
     "Cancel" : "لغو",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
     "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
