@@ -24,6 +24,7 @@ OC.L10N.register(
     "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
     "Unsupported file type for import" : "Tiedoston tyyppi ei ole tuotavaa muotoa",
     "Bookmarks shared by %s" : "Henkilön %s jakamat kirjanmerkit",
+    "Recent Bookmarks" : "Uusimmat kirjanmerkit",
     "Bookmark" : "Kirjanmerkki",
     "Bookmark deleted" : "Kirjanmerkki poistettu",
     "Bookmark created" : "Kirjanmerkki luotu",
@@ -36,6 +37,7 @@ OC.L10N.register(
     "Rename" : "Nimeä uudelleen",
     "Move" : "Siirrä",
     "Delete" : "Poista",
+    "Search" : "Etsi",
     "Select one or more tags" : "Valitse yksi tai useampi tunniste",
     "New" : "Uusi",
     "New bookmark" : "Uusi kirjanmerkki",
@@ -55,6 +57,7 @@ OC.L10N.register(
     "Enter folder title" : "Anna nimi kansiolle",
     "Shared by {user}" : "Jakanut {user}",
     "Root folder" : "Juurikansio",
+    "Submit" : "Lähetä",
     "Cancel" : "Peruuta",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
     "_Moving %n folder_::_Moving %n folders_" : ["Siirretään %n kansio","Siirretään %n kansiota"],
