@@ -5,12 +5,14 @@ OC.L10N.register(
     "No file provided for import" : "לא סופק קובץ לייבוא",
     "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
     "Bookmarks shared by %s" : "סימניות שמשותפות על ידי %s",
+    "Recent Bookmarks" : "סימניות אחרונות",
     "A Bookmark manager for Nextcloud" : "מנהל סימניות ל־Nextcloud",
     "Select bookmark" : "בחירת סימנייה",
     "Details" : "פרטים",
     "Rename" : "שינוי שם",
     "Move" : "העברה",
     "Delete" : "מחיקה",
+    "Search" : "חיפוש",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
     "New" : "חדש",
     "New bookmark" : "סימנייה חדשה",
@@ -30,6 +32,7 @@ OC.L10N.register(
     "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
     "Root folder" : "תיקיית בסיס",
+    "Submit" : "שליחה",
     "Cancel" : "ביטול",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["תיקייה אחת ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות","%n תיקיות ומספר סימניות מועברות"],
     "_Moving %n folder_::_Moving %n folders_" : ["תיקייה אחת מועברת","%n תיקיות מועברות","%n תיקיות מועברות","%n תיקיות מועברות"],
