@@ -28,6 +28,7 @@ OC.L10N.register(
     "No file provided for import" : "Nije navedena datoteka za uvoz",
     "Unsupported file type for import" : "Nepodržana vrsta datoteke za uvoz",
     "Bookmarks shared by %s" : "Knjižne oznake dijeljene s %s",
+    "Recent Bookmarks" : "Nedavne knjižne oznake",
     "Bookmark" : "Dodaj knjižnu oznaku",
     "Bookmark deleted" : "Knjižna oznaka je izbrisana",
     "Bookmark created" : "Knjižna oznaka je stvorena",
@@ -41,6 +42,7 @@ OC.L10N.register(
     "Rename" : "Preimenuj",
     "Move" : "Premjesti",
     "Delete" : "Izbriši",
+    "Search" : "Traži",
     "Select one or more tags" : "Odaberite jednu ili više oznaka",
     "New" : "Novo",
     "New bookmark" : "Nova knjižna oznaka",
@@ -60,6 +62,7 @@ OC.L10N.register(
     "Enter folder title" : "Unesite naslov mape",
     "Shared by {user}" : "Dijeli {user}",
     "Root folder" : "Korijenska mapa",
+    "Submit" : "Šalji",
     "Cancel" : "Odustani",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mape i nekih knjižnih oznaka","Premještanje %n mapa i nekih knjižnih oznaka"],
     "_Moving %n folder_::_Moving %n folders_" : ["Premještanje %n mape","Premještanje %n mape","Premještanje %n mapa"],
