@@ -4,12 +4,14 @@ OC.L10N.register(
     "Bookmarks" : "Könyvjelzők",
     "No file provided for import" : "Nincs fájl megadva importáláshoz",
     "Unsupported file type for import" : "Nem támogatott fájltípus az importáláshoz",
+    "Recent Bookmarks" : "Legújabb könyvjelzők",
     "A Bookmark manager for Nextcloud" : "Könyvjelző kezelő Nextcloud-hoz",
     "Select bookmark" : "Válasszon könyvjelzőt",
     "Details" : "Részletek",
     "Rename" : "Átnevezés",
     "Move" : "Áthelyezés",
     "Delete" : "Törlés",
+    "Search" : "Keresés",
     "Select one or more tags" : "Válasszon egy vagy több címkét",
     "New" : "Új",
     "New folder" : "Új mappa",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Enter a link" : "Adjon meg egy hivatkozást",
     "Enter folder title" : "Adja meg a mappa nevét",
     "Root folder" : "Gyökérmappa",
+    "Submit" : "Beküldés",
     "Cancel" : "Mégse",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n mappa és néhány könyvjelző áthelyezése","%n mappa és néhány könyvjelző áthelyezése"],
     "_Moving %n folder_::_Moving %n folders_" : ["%n mappa áthelyezése","%n mappa áthelyezése"],
@@ -60,7 +63,7 @@ OC.L10N.register(
     "Select" : "Kijelölés",
     "Previews" : "Előnézetek",
     "Screeenly" : "Screeenly",
-    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
+    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screeenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API-kulcs",
     "Privacy" : "Adatvédelem",
