@@ -5,21 +5,22 @@ OC.L10N.register(
     "Rename" : "Վերանվանել",
     "Move" : "Move",
     "Delete" : "հեռացնել",
-    "Save" : "Պահպանել",
+    "Search" : "Search",
+    "New" : "Նոր",
     "New folder" : "Նոր պանակ",
-    "Create" : "Ստեղծել",
+    "Select all" : "Նշել բոլորը",
     "Cancel" : "ընդհատել",
     "Import" : "Ներմուծում",
     "Export" : "Արտահանում",
-    "URL" : "URL",
+    "Title" : "Վերնագիր",
+    "Link" : "Հղում",
     "Notes" : "Notes",
     "Owner" : "Owner",
     "Share link" : "Կիսվել հղմամբ",
     "Copy link" : "Պատճենել հղումը",
     "Allow editing" : "Թույլատրել խմբագրումը",
     "Select" : "Select",
-    "Title" : "Վերնագիր",
-    "Link" : "Հղում",
-    "Folder" : "Պանակ"
+    "Folder" : "Պանակ",
+    "Save" : "Պահպանել"
 },
 "nplurals=2; plural=(n != 1);");
