@@ -5,12 +5,14 @@ OC.L10N.register(
     "No file provided for import" : "Engin skrá valin til innflutnings",
     "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Bookmarks shared by %s" : "Bókamerki deilt af %s",
+    "Recent Bookmarks" : "Nýleg bókamerki",
     "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
     "Select bookmark" : "Veldu bókamerki",
     "Details" : "Nánar",
     "Rename" : "Endurnefna",
     "Move" : "Færa",
     "Delete" : "Eyða",
+    "Search" : "Search",
     "Select one or more tags" : "Veldu eitt eða fleiri merki",
     "New" : "Nýtt",
     "New bookmark" : "Nýtt bókamerki",
@@ -30,6 +32,7 @@ OC.L10N.register(
     "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
     "Root folder" : "Rótarmappa",
+    "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
     "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
