@@ -5,12 +5,14 @@ OC.L10N.register(
     "No file provided for import" : "インポート用に提供されたファイルがありません",
     "Unsupported file type for import" : "インポートでサポートされていないファイル形式です",
     "Bookmarks shared by %s" : "%s から共有されたブックマーク",
+    "Recent Bookmarks" : "最新のブックマーク",
     "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
     "Select bookmark" : "ブックマークを選択",
     "Details" : "詳細",
     "Rename" : "名前の変更",
     "Move" : "移動",
     "Delete" : "削除",
+    "Search" : "検索",
     "Select one or more tags" : "1つ以上のタグを選択",
     "New" : "新規作成",
     "New bookmark" : "新しいブックマーク",
@@ -30,6 +32,7 @@ OC.L10N.register(
     "Enter folder title" : "フォルダーのタイトルを入力",
     "Shared by {user}" : "{user} から共有されました",
     "Root folder" : "ルートフォルダー",
+    "Submit" : "送信",
     "Cancel" : "キャンセル",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n個のフォルダーといくつかのブックマークを移動中"],
     "_Moving %n folder_::_Moving %n folders_" : ["%n個のフォルダーを移動中"],
