@@ -4,21 +4,22 @@ OC.L10N.register(
     "Rename" : "﻿ಮರುಹೆಸರಿಸು",
     "Move" : "Move",
     "Delete" : "﻿ಅಳಿಸಿ",
-    "Save" : "﻿ಉಳಿಸಿ",
+    "Search" : "Search",
+    "New" : "﻿ಹೊಸ",
     "New folder" : "﻿ಹೊಸ ಕೋಶ",
-    "Create" : "ಸೃಷ್ಟಿಸಿ",
+    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
     "Cancel" : "﻿ರದ್ದು",
     "Import" : "ಆಮದು",
     "Export" : "ರಫ್ತು",
-    "URL" : "ಜಾಲದ ಕೊಂಡಿ",
+    "Title" : "ಶೀರ್ಷಿಕೆ",
+    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
     "Notes" : "Notes",
-    "Sharing" : "﻿ಹಂಚಿಕೆ",
     "Owner" : "Owner",
+    "Sharing" : "﻿ಹಂಚಿಕೆ",
     "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
     "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
     "Select" : "Select",
-    "Title" : "ಶೀರ್ಷಿಕೆ",
-    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
-    "Folder" : "ಕೋಶ"
+    "Folder" : "ಕೋಶ",
+    "Save" : "﻿ಉಳಿಸಿ"
 },
 "nplurals=2; plural=(n > 1);");
