@@ -5,24 +5,26 @@ OC.L10N.register(
     "Rename" : "Ëmbenennen",
     "Move" : "Verschieben",
     "Delete" : "Läschen",
-    "Save" : "Späicheren",
+    "Search" : "Search",
+    "New" : "Nei",
     "New folder" : "Neien Dossier",
-    "Create" : "Erstellen",
+    "Select all" : "All auswielen",
     "Cancel" : "Ofbriechen",
+    "Recent" : "Rezent",
     "Import" : "Importéieren",
     "Export" : "Exportéieren",
     "Clear data" : "Donnéeë läschen",
-    "URL" : "URL",
+    "Title" : "Titel",
+    "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notizen",
-    "Sharing" : "Gedeelt",
     "Owner" : "Owner",
+    "Sharing" : "Gedeelt",
     "Share link" : "Link deelen",
     "Copy link" : "Link kopéieren",
     "Allow editing" : "Beaarbechten erlaben",
     "Select" : "Select",
-    "Title" : "Titel",
-    "Link" : "Link",
-    "Folder" : "Dossier"
+    "Folder" : "Dossier",
+    "Save" : "Späicheren"
 },
 "nplurals=2; plural=(n != 1);");
