@@ -10,6 +10,7 @@ OC.L10N.register(
     "New folder" : "Нова папка",
     "Grid view" : "Мрежа",
     "List view" : "Листа",
+    "RSS Feed of current view" : "RSS канал од моменталниот поглед",
     "Select all" : "Избери се",
     "Submit" : "Испрати",
     "Cancel" : "Откажи",
@@ -22,13 +23,16 @@ OC.L10N.register(
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
+    "Attachments" : "Прилози",
     "Notes" : "Белешки",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
     "Share link" : "Сподели линк",
     "Copy link" : "Копирај линк",
+    "Copy RSS feed" : "Копирај RSS канал",
     "Allow editing" : "Овозможи уредување",
     "Link copied" : "Линкот е копиран",
+    "RSS feed copied" : "RSS канал копиран",
     "Select" : "Select",
     "Privacy" : "Приватност",
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
