@@ -1,6 +1,16 @@
 OC.L10N.register(
     "bookmarks",
     {
+    "Bookmarks" : "Тэмдэглэж авах",
+    "You bookmarked \"%s\"" : "Тэмдэглэж авлаа \"%s\"",
+    "You deleted \"%s\"" : "\"%s\"-ийг та устгалаа",
+    "%1$s deleted \"%2$s\"" : "\"%2$s\"-ийг %1$s устгалаа ",
+    "Someone deleted \"%s\"" : "\"%s\" устгагдлаа",
+    "You created folder \"%s\"" : "Та \"%s\" фолдерыг үүсгэлээ",
+    "%1$s created folder \"%2$s\"" : "\"%2$s\" фолдерыг %1$s шинээр үүсгэлээ",
+    "Someone created folder \"%s\"" : "\"%s\" фолдерыг шинээр үүсгэлээ",
+    "You moved folder \"%s\"" : "Та \"%s\" фолдерыг  хөдөлгөлөө",
+    "%1$s moved folder \"%2$s\"" : "\"%2$s\" фолдерыг %1$s хөдөлгөлөө",
     "Details" : "Дэлгэрэнгүй",
     "Rename" : "Нэрлэнэ үү",
     "Move" : "Зөөх",
