@@ -5,24 +5,24 @@ OC.L10N.register(
     "Rename" : "Gje nytt namn",
     "Move" : "Move",
     "Delete" : "Ta bort",
-    "Save" : "Lagre",
+    "Search" : "Search",
+    "New" : "Ny",
     "New folder" : "Ny mappe",
-    "Create" : "Lag",
     "Cancel" : "Avbryt",
     "Import" : "Importer",
     "Export" : "Eksporter",
     "Recently added" : "Nyleg lagt til",
     "Last modified" : "Siste endra",
-    "URL" : "URL",
+    "Title" : "Tittel",
+    "Link" : "Lenkje",
     "Tags" : "Emneord",
     "Notes" : "Notat",
-    "Sharing" : "Deling",
     "Owner" : "Owner",
+    "Sharing" : "Deling",
     "Share link" : "Del lenkje",
     "Allow editing" : "Tillat endring",
     "Select" : "Vel",
-    "Title" : "Tittel",
-    "Link" : "Lenkje",
-    "Folder" : "Mappe"
+    "Folder" : "Mappe",
+    "Save" : "Lagre"
 },
 "nplurals=2; plural=(n != 1);");
