@@ -6,12 +6,14 @@ OC.L10N.register(
     "Rename" : "Renomear",
     "Move" : "Mover",
     "Delete" : "Apagar",
+    "Search" : "Pesquisa sobre",
     "New" : "Novo",
     "New folder" : "Nova pasta",
     "Grid view" : "Vista em grelha",
     "List view" : "Vista em lista",
     "Select all" : "Seleccionar todos",
     "Root folder" : "Pasta raiz",
+    "Submit" : "Submeter",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos os marcadores",
     "Recent" : "Recentes",
