@@ -5,11 +5,13 @@ OC.L10N.register(
     "Rename" : "Redenumire",
     "Move" : "Mută",
     "Delete" : "Șterge",
+    "Search" : "Caută",
     "New" : "Nou",
     "New folder" : "Director nou",
     "Grid view" : "Afișare în grilă",
     "List view" : "Afișare în listă",
     "Select all" : "Selectează tot",
+    "Submit" : "Trimite",
     "Cancel" : "Anulează",
     "Recent" : "Recente",
     "Import" : "Importă",
