@@ -6,6 +6,7 @@ OC.L10N.register(
     "%1$s bookmarked \"%2$s\"" : "%1$s создал закладку \"%2$s\"",
     "Someone bookmarked \"%s\"" : "Кто-то создал закладку \"%s\"",
     "You deleted \"%s\"" : "Вы удалили \"%s\"",
+    "%1$s deleted \"%2$s\"" : "%1$s удалена \"%2$s\"",
     "Someone deleted \"%s\"" : "Кто-то удалил \"%s\"",
     "You created folder \"%s\"" : "Вы создали папку \"%s\"",
     "%1$s created folder \"%2$s\"" : "%1$s создал папку \"%2$s\"",
@@ -27,12 +28,16 @@ OC.L10N.register(
     "No file provided for import" : "Не указан файл для импорта",
     "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
     "Bookmarks shared by %s" : "Закладки предоставлены пользователем %s ",
+    "Recent Bookmarks" : "Последние закладки",
+    "Bookmark" : "Закладка",
+    "Bookmark deleted" : "Закладка удалена",
     "A Bookmark manager for Nextcloud" : "Менеджер закладок для Nextcloud",
     "Select bookmark" : "Выберите закладки",
     "Details" : "Подробнее",
     "Rename" : "Переименовать",
     "Move" : "Переместить",
     "Delete" : "Удалить",
+    "Search" : "Поиск",
     "Select one or more tags" : "Выберите одну или больше меток",
     "New" : "Новая",
     "New bookmark" : "Новая закладка",
@@ -52,6 +57,7 @@ OC.L10N.register(
     "Enter folder title" : "Введите название папки",
     "Shared by {user}" : "Опубликовано пользователем {user} ",
     "Root folder" : "Корневая папка",
+    "Submit" : "Создать",
     "Cancel" : "Отмена",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Перемещаем %n папку и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки"],
     "_Moving %n folder_::_Moving %n folders_" : ["Перемещаем %n папку","Перемещаем %n папок","Перемещаем %n папок","Перемещаем %n папок"],
@@ -102,7 +108,7 @@ OC.L10N.register(
     "Previews" : "Предварительный просмотр",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Для того, чтобы показать реальный вид сайтов в ваших закладках, приложение \"Закладки\" может использовать сторонние сервисы для создания изображения",
     "Screeenly" : "Screenly",
-    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screenly.com или настроить свой сервер.",
+    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screeenly.com или настроить свой сервер.",
     "Screeenly API URL" : "Ссылка на Screenly API",
     "Screeenly API key" : "API-ключ Screeenly",
     "Privacy" : "Приватность",
