@@ -4,20 +4,20 @@ OC.L10N.register(
     "Rename" : "නැවත නම් කරන්න",
     "Move" : "Move",
     "Delete" : "ඉවත් කරන්න",
-    "Save" : "සුරකින්න",
-    "Create" : "තනන්න",
+    "Search" : "Search",
+    "New" : "නව",
     "Cancel" : "අවලංගු කරන්න",
     "Import" : "ආයාත කරන්න",
     "Export" : "නිර්යාත කරන්න",
-    "URL" : "URL",
-    "Tags" : "ටැග",
-    "Notes" : "සටහන්",
-    "Sharing" : "හුවමාරු කිරීම",
-    "Owner" : "Owner",
-    "Share link" : "Share link",
-    "Select" : "Select",
     "Title" : "මාතෘකාව",
     "Link" : "Link",
-    "Folder" : "ෆෝල්ඩරය"
+    "Tags" : "ටැග",
+    "Notes" : "සටහන්",
+    "Owner" : "Owner",
+    "Sharing" : "හුවමාරු කිරීම",
+    "Share link" : "Share link",
+    "Select" : "Select",
+    "Folder" : "ෆෝල්ඩරය",
+    "Save" : "සුරකින්න"
 },
 "nplurals=2; plural=(n != 1);");
