@@ -27,10 +27,12 @@ OC.L10N.register(
     "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
     "Unsupported file type for import" : "Nepodporovaný typ súboru na import",
     "Bookmarks shared by %s" : "Záložky, ktoré zdieľa %s",
+    "Recent Bookmarks" : "Aktuálne záložky",
     "Bookmark" : "Záložka",
     "Bookmark deleted" : "Záložka zmazaná",
     "Bookmark created" : "Záložka vytvorená",
     "Bookmark moved" : "Záložka presunutá",
+    "Bookmark updated" : "Záložka auktualizovaná",
     "Create bookmark" : "Vytvoriť záložku",
     "A Bookmark manager for Nextcloud" : "Manažér záložiek pre Nextcloud",
     "Select bookmark" : "Vybrať záložku",
@@ -38,6 +40,7 @@ OC.L10N.register(
     "Rename" : "Premenovať",
     "Move" : "Presunúť",
     "Delete" : "Zmazať",
+    "Search" : "Hľadať",
     "Select one or more tags" : "Zvoliť jeden alebo viac štítkov",
     "New" : "Nový",
     "New bookmark" : "Nová záložka",
@@ -57,12 +60,15 @@ OC.L10N.register(
     "Enter folder title" : "Zadať názov priečinka",
     "Shared by {user}" : "Zdieľa {user}",
     "Root folder" : "Koreňový priečinok",
+    "Submit" : "Odoslať",
     "Cancel" : "Zrušiť",
+    "Deleting selection" : "Maže sa výber",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Presúva sa %n priečinok a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúva sa %n priečinkov a niektoré záložky"],
     "_Moving %n folder_::_Moving %n folders_" : ["Presúva sa %n priečinok","Presúvajú sa %n priečinky","Presúvajú sa %n priečinky","Presúva sa %n priečinkov"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Presúva sa %n záložka","Presúvajú sa %n záložky","Presúvajú sa %n záložky","Presúva sa %n záložiek"],
     "All bookmarks" : "Všetky záložky",
     "Recent" : "Nedávne",
+    "Archived" : "Archivované",
     "Untagged" : "Bez štítku",
     "{used} bookmarks of {available} available" : "{used} záložky z {available} dostupných",
     "No archived bookmarks" : "Žiadne archivované záložky",
@@ -90,6 +96,8 @@ OC.L10N.register(
     "Creation date" : "Dátum vytvorenia",
     "Tags" : "Štítky",
     "Attachments" : "Prílohy",
+    "Archived version" : "Archivovaná verzia",
+    "Open archived file" : "Otvoriť archivovaný súbor",
     "Notes" : "Poznámky",
     "{time} ago" : "Pred {time} ",
     "Owner" : "Majiteľ",
