@@ -5,12 +5,14 @@ OC.L10N.register(
     "No file provided for import" : "није дат фајл за увоз",
     "Unsupported file type for import" : "врста фајла за увоз није подржана",
     "Bookmarks shared by %s" : "%s поделио обележиваче",
+    "Recent Bookmarks" : "Недавни обележивачи",
     "A Bookmark manager for Nextcloud" : "Менаџер обележивача за Некстклауд",
     "Select bookmark" : "Изабери обележивач",
     "Details" : "Детаљи",
     "Rename" : "Преименуј",
     "Move" : "Премести",
     "Delete" : "Обриши",
+    "Search" : "Претрага",
     "Select one or more tags" : "Одаберите једну или више ознака",
     "New" : "Нов",
     "New bookmark" : "Нови обележивач",
@@ -30,6 +32,7 @@ OC.L10N.register(
     "Enter folder title" : "Унесите назив фасцикле",
     "Shared by {user}" : "Поделио {user}",
     "Root folder" : "Корена фасцикла",
+    "Submit" : "Пошаљи",
     "Cancel" : "Поништи",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Премештам %n фасциклу и неке обележиваче","Премештам %n фасцикле и неке обележиваче","Премештам %n фасцикли и неке обележиваче"],
     "_Moving %n folder_::_Moving %n folders_" : ["Премештам %n фасциклу","Премештам %n фасцикле","Премештам %n фасцикли "],
