@@ -5,29 +5,31 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
-    "Save" : "Save",
+    "Search" : "Traži",
+    "New" : "Nov",
     "New folder" : "Nova fascikla",
     "Grid view" : "Prikaz mreže",
     "List view" : "Prikaz liste",
-    "Create" : "Napravi",
-    "Cancel" : "Otkaži",
+    "Select all" : "Označi sve",
     "Root folder" : "Korena fascikla",
+    "Cancel" : "Otkaži",
     "Import" : "Uvezi",
     "Recently added" : "Nedavno dodato",
     "Clear data" : "Očisti podatke",
-    "URL" : "Url",
+    "Title" : "Naslov",
+    "Link" : "Prečica",
     "Tags" : "Oznake",
+    "Attachments" : "Prilozi",
     "Notes" : "Notes",
-    "Sharing" : "Deljenje",
     "Owner" : "Vlasnik",
+    "Sharing" : "Deljenje",
     "Share link" : "Podeli vezu",
     "Copy link" : "Kopiraj vezu",
     "Allow editing" : "Dozvoli uređivanje",
     "Link copied" : "Veza iskopirana",
     "Select" : "Select",
     "Privacy" : "Privatnost",
-    "Title" : "Naslov",
-    "Link" : "Prečica",
-    "Folder" : "Folder"
+    "Folder" : "Folder",
+    "Save" : "Save"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
