@@ -5,19 +5,19 @@ OC.L10N.register(
     "Rename" : "பெயர்மாற்றம்",
     "Move" : "Move",
     "Delete" : "நீக்குக",
-    "Save" : "சேமிக்க ",
-    "Create" : "உருவாக்குக",
+    "Search" : "Search",
+    "New" : "புதிய",
     "Cancel" : "இரத்து செய்க",
     "Import" : "இறக்குமதி",
     "Export" : "ஏற்றுமதி",
-    "URL" : "URL",
+    "Title" : "தலைப்பு",
+    "Link" : "Link",
     "Tags" : "சீட்டுகள்",
     "Notes" : "குறிப்புகள்",
     "Owner" : "Owner",
     "Share link" : "Share link",
     "Select" : "Select",
-    "Title" : "தலைப்பு",
-    "Link" : "Link",
-    "Folder" : "கோப்புறை"
+    "Folder" : "கோப்புறை",
+    "Save" : "சேமிக்க "
 },
 "nplurals=2; plural=(n != 1);");
