@@ -8,11 +8,13 @@ OC.L10N.register(
     "Rename" : "Перейменувати",
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
+    "Search" : "Пошук",
     "New" : "Створити",
     "New folder" : "Нова тека",
     "Grid view" : "Упорядкування у формі сітки",
     "List view" : "Упорядкування у формі списку",
     "Select all" : "Вибрати все",
+    "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
     "Recent" : "Нещодавні",
     "Add a bookmark" : "Додати закладку",
