@@ -5,12 +5,14 @@ OC.L10N.register(
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
     "Bookmarks shared by %s" : "书签共享者 %s",
+    "Recent Bookmarks" : "近期书签",
     "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
     "Select bookmark" : "选择书签",
     "Details" : "详情",
     "Rename" : "重命名",
     "Move" : "移动",
     "Delete" : "删除",
+    "Search" : "搜索",
     "Select one or more tags" : "选择一个或多个标签",
     "New" : "新建",
     "New bookmark" : "新建书签",
@@ -26,6 +28,7 @@ OC.L10N.register(
     "Enter folder title" : "输入文件夹标题",
     "Shared by {user}" : "由 {user} 共享",
     "Root folder" : "根文件夹",
+    "Submit" : "提交",
     "Cancel" : "取消",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移动%n个文件夹和一些书签"],
     "_Moving %n folder_::_Moving %n folders_" : ["正在移动%n个文件夹"],
