@@ -4,23 +4,23 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Move" : "Move",
     "Delete" : "刪除",
-    "Save" : "儲存",
+    "Search" : "Search",
+    "New" : "新增",
     "New folder" : "新文件夾",
-    "Create" : "新增",
     "Cancel" : "取消",
     "Import" : "導入",
     "Export" : "滙出",
     "Recently added" : "最近加入",
-    "URL" : "網址",
+    "Title" : "標題",
+    "Link" : "Link",
     "Notes" : "筆記",
-    "Sharing" : "分享",
     "Owner" : "Owner",
+    "Sharing" : "分享",
     "Share link" : "分享連結",
     "Copy link" : "複製連結",
     "Allow editing" : "容許編輯",
     "Select" : "Select",
-    "Title" : "標題",
-    "Link" : "Link",
-    "Folder" : "資料夾"
+    "Folder" : "資料夾",
+    "Save" : "儲存"
 },
 "nplurals=1; plural=0;");
