@@ -189,6 +189,9 @@ class BookmarkMapper extends QBMapper {
 		$qb->select($bookmark_cols);
 		$qb->groupBy($bookmark_cols);
 
+		$this->_selectFolders($qb);
+		$this->_selectTags($qb);
+
 		$qb
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
@@ -196,16 +199,19 @@ class BookmarkMapper extends QBMapper {
 				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
 			))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
+			->leftJoin('tr', 'bookmarks_tree', 'tr2', $qb->expr()->andX(
+				$qb->expr()->eq('tr2.id', 'tr.parent_folder'),
+				$qb->expr()->eq('tr2.type', $qb->createPositionalParameter(TreeMapper::TYPE_FOLDER))
+			))
+			->leftJoin('tr2', 'bookmarks_shared_folders', 'sf2', $qb->expr()->eq('tr2.parent_folder', 'sf.folder_id'))
 			->where(
 				$qb->expr()->orX(
 					$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
-					$qb->expr()->eq('sf.user_id', $qb->createPositionalParameter($userId))
+					$qb->expr()->eq('sf.user_id', $qb->createPositionalParameter($userId)),
+					$qb->expr()->eq('sf2.user_id', $qb->createPositionalParameter($userId))
 				)
 			);
 
-		$this->_selectFolders($qb);
-		$this->_selectTags($qb);
-
 		$this->_filterUrl($qb, $params);
 		$this->_filterArchived($qb, $params);
 		$this->_filterUnavailable($qb, $params);
@@ -385,7 +391,10 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->eq('tr.id', 'b.id'))
+			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
+				$qb->expr()->eq('b.id', 'tr.id'),
+				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
+			))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
 			->where($qb->expr()->orX(
 				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
@@ -406,7 +415,10 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->eq('tr.id', 'b.id'))
+			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
+				$qb->expr()->eq('b.id', 'tr.id'),
+				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
+			))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
 			->where($qb->expr()->orX(
 				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
@@ -437,6 +449,9 @@ class BookmarkMapper extends QBMapper {
 		$qb->select($bookmark_cols);
 		$qb->groupBy($bookmark_cols);
 
+		$this->_selectFolders($qb);
+		$this->_selectTags($qb);
+
 		$qb
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
@@ -449,14 +464,11 @@ class BookmarkMapper extends QBMapper {
 			))
 			->where(
 				$qb->expr()->orX(
-					$qb->expr()->eq('tr.parent_folder', $qb->createPositionalParameter($publicFolder->getFolderId())),
-					$qb->expr()->eq('tr2.parent_folder', $qb->createPositionalParameter($publicFolder->getFolderId()))
+					$qb->expr()->eq('tr.parent_folder', $qb->createPositionalParameter($publicFolder->getFolderId(), IQueryBuilder::PARAM_INT)),
+					$qb->expr()->eq('tr2.parent_folder', $qb->createPositionalParameter($publicFolder->getFolderId(), IQueryBuilder::PARAM_INT))
 				)
 			);
 
-		$this->_selectFolders($qb);
-		$this->_selectTags($qb);
-
 		$this->_filterUrl($qb, $params);
 		$this->_filterArchived($qb, $params);
 		$this->_filterUnavailable($qb, $params);
@@ -607,7 +619,10 @@ class BookmarkMapper extends QBMapper {
 	 * @param IQueryBuilder $qb
 	 */
 	private function _selectFolders(IQueryBuilder $qb): void {
-		$qb->leftJoin('b', 'bookmarks_tree', 'tree', $qb->expr()->eq('b.id', 'tree.id'));
+		$qb->leftJoin('b', 'bookmarks_tree', 'tree', $qb->expr()->andX(
+			$qb->expr()->eq('b.id', 'tree.id'),
+			$qb->expr()->eq('tree.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
+		));
 		if ($this->getDbType() === 'pgsql') {
 			$folders = $qb->createFunction('array_to_string(array_agg(' . $qb->getColumnName('tree.parent_folder') . "), ',')");
 		} else {
