@@ -1,25 +1,13 @@
 <?php
-/**
- * @author Marcel Klehr
- * @copyright 2018 Marcel Klehr mklehr@gmx.net
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
  *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 
 namespace OCA\Bookmarks\Service;
 
+use Exception;
 use OCA\Bookmarks\Contract\IBookmarkPreviewer;
 use OCA\Bookmarks\Contract\IImage;
 use OCA\Bookmarks\Db\Bookmark;
@@ -28,7 +16,7 @@ use OCP\Files\NotFoundException;
 use OCP\Files\NotPermittedException;
 use OCP\Http\Client\IClient;
 use OCP\Http\Client\IClientService;
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 
 class FaviconPreviewer implements IBookmarkPreviewer {
 	public const CACHE_TTL = 4 * 4 * 7 * 24 * 60 * 60; // cache for one month
@@ -46,7 +34,7 @@ class FaviconPreviewer implements IBookmarkPreviewer {
 	private $linkExplorer;
 
 	/**
-	 * @var ILogger
+	 * @var LoggerInterface
 	 */
 	private $logger;
 
@@ -63,7 +51,7 @@ class FaviconPreviewer implements IBookmarkPreviewer {
 	 */
 	private $enabled;
 
-	public function __construct(FileCache $cache, LinkExplorer $linkExplorer, ILogger $logger, IClientService $clientService, \OCP\IConfig $config) {
+	public function __construct(FileCache $cache, LinkExplorer $linkExplorer, LoggerInterface $logger, IClientService $clientService, \OCP\IConfig $config) {
 		$this->cache = $cache;
 		$this->linkExplorer = $linkExplorer;
 		$this->logger = $logger;
@@ -123,7 +111,7 @@ class FaviconPreviewer implements IBookmarkPreviewer {
 		return null;
 	}
 
-	public function scrapeUrl($url) {
+	public function scrapeUrl($url): array {
 		return $this->linkExplorer->get($url);
 	}
 
@@ -131,11 +119,11 @@ class FaviconPreviewer implements IBookmarkPreviewer {
 	 * @param $url
 	 * @return Image|null
 	 */
-	protected function fetchImage($url): ?Image {
+	protected function fetchImage(string $url): ?Image {
 		try {
 			$response = $this->client->get($url, ['timeout' => self::HTTP_TIMEOUT]);
-		} catch (\Exception $e) {
-			$this->logger->debug($e, ['app' => 'bookmarks']);
+		} catch (Exception $e) {
+			$this->logger->debug($e->getMessage(), ['app' => 'bookmarks']);
 			return null;
 		}
 		$body = $response->getBody();
