@@ -1,28 +1,8 @@
 <?php
-/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Joas Schilling <coding@schilljs.com>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
- * @author Sebastian Wessalowski <sebastian@wessalowski.org>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Vincent Petry <pvince81@owncloud.com>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
  *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 
 namespace OCA\Bookmarks\Service;
@@ -67,7 +47,7 @@ class FileCache implements ICache {
 	 * @return int
 	 * @throws NotFoundException
 	 */
-	public function size($key) {
+	public function size($key): int {
 		$result = 0;
 		if ($this->hasKey($key)) {
 			$result = $this->storage->getFile($key)->getSize();
@@ -124,7 +104,7 @@ class FileCache implements ICache {
 	 *
 	 * @throws NotPermittedException
 	 */
-	public function gc() {
+	public function gc(): void {
 		foreach ($this->storage->getDirectoryListing() as $file) {
 			if (time() - self::TIMEOUT > $file->getMTime()) {
 				$file->delete();
