@@ -1,4 +1,9 @@
 <?php
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
 
 namespace OCA\Bookmarks\Service;
 
@@ -7,15 +12,18 @@ use OCA\Bookmarks\Db\FolderMapper;
 use OCA\Bookmarks\Db\SharedFolderMapper;
 use OCA\Bookmarks\Db\ShareMapper;
 use OCA\Bookmarks\Db\TreeMapper;
+use OCA\Bookmarks\Db\Folder;
 use OCA\Bookmarks\Events\ChangeEvent;
 use OCA\Bookmarks\Events\MoveEvent;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
+use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventListener;
 use OCP\ICache;
 use OCP\ICacheFactory;
 use UnexpectedValueException;
 
-class HashManager {
+class HashManager implements IEventListener {
 
 	/**
 	 * @var ICache
@@ -41,6 +49,10 @@ class HashManager {
 	 * @var FolderMapper
 	 */
 	protected $folderMapper;
+	/**
+	 * @var bool
+	 */
+	private $enabled = true;
 
 	/**
 	 * FolderMapper constructor.
@@ -64,7 +76,6 @@ class HashManager {
 	/**
 	 * @param string $type
 	 * @param int $folderId
-	 * @param string $userId
 	 * @return string
 	 */
 	private function getCacheKey(string $type, int $folderId) : string {
@@ -125,7 +136,9 @@ class HashManager {
 			$hash = [];
 		}
 
+		/** @var Folder $entity */
 		$entity = $this->folderMapper->find($folderId);
+		$rootFolder = $this->folderMapper->findRootFolder($userId);
 		$children = $this->treeMapper->getChildrenOrder($folderId);
 		$childHashes = array_map(function ($item) use ($fields, $entity) {
 			switch ($item['type']) {
@@ -140,11 +153,11 @@ class HashManager {
 		$folder = [];
 		if ($entity->getUserId() !== $userId) {
 			$folder['title'] = $this->sharedFolderMapper->findByFolderAndUser($folderId, $userId)->getTitle();
-		} elseif ($entity->getTitle() !== null) {
+		} elseif ($entity->getTitle() !== null && $entity->getId() !== $rootFolder->getId()) {
 			$folder['title'] = $entity->getTitle();
 		}
 		$folder['children'] = $childHashes;
-		$hash[$selector] = hash('sha256', json_encode($folder, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
+		$hash[$selector] = hash('sha256', json_encode($folder, JSON_THROW_ON_ERROR | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
 
 		$this->cache->set($key, $hash, 60 * 60 * 24);
 		return $hash[$selector];
@@ -171,11 +184,9 @@ class HashManager {
 		$entity = $this->bookmarkMapper->find($bookmarkId);
 		$bookmark = [];
 		foreach ($fields as $field) {
-			if (isset($entity->{$field})) {
-				$bookmark[$field] = $entity->{'get' . $field}();
-			}
+			$bookmark[$field] = $entity->{'get' . $field}();
 		}
-		$hash[$selector] = hash('sha256', json_encode($bookmark, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
+		$hash[$selector] = hash('sha256', json_encode($bookmark, JSON_THROW_ON_ERROR | JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
 		$this->cache->set($key, $hash, 60 * 60 * 24);
 		return $hash[$selector];
 	}
@@ -183,9 +194,15 @@ class HashManager {
 	/**
 	 * Handle events
 	 *
-	 * @param ChangeEvent $event
+	 * @param Event $event
 	 */
-	public function handle(ChangeEvent $event): void {
+	public function handle(Event $event): void {
+		if ($this->enabled === false) {
+			return;
+		}
+		if (!($event instanceof ChangeEvent)) {
+			return;
+		}
 		switch ($event->getType()) {
 			case TreeMapper::TYPE_FOLDER:
 				$this->invalidateFolder($event->getId());
@@ -203,4 +220,8 @@ class HashManager {
 			}
 		}
 	}
+
+	public function setInvalidationEnabled(bool $enabled): void {
+		$this->enabled = $enabled;
+	}
 }
