@@ -1,34 +1,21 @@
 <?php
-/**
- * @author Marcel Klehr
- * @copyright 2016 Marcel Klehr mklehr@gmx.net
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
  *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 
 namespace OCA\Bookmarks\Service\Previewers;
 
+use Exception;
 use OCA\Bookmarks\Contract\IBookmarkPreviewer;
 use OCA\Bookmarks\Contract\IImage;
 use OCA\Bookmarks\Db\Bookmark;
 use OCA\Bookmarks\Image;
-use OCA\Bookmarks\Service\FileCache;
 use OCA\Bookmarks\Service\LinkExplorer;
 use OCP\Http\Client\IClient;
 use OCP\Http\Client\IClientService;
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 
 class DefaultBookmarkPreviewer implements IBookmarkPreviewer {
 	public const CACHE_PREFIX = 'bookmarks.DefaultPreviewService';
@@ -40,16 +27,15 @@ class DefaultBookmarkPreviewer implements IBookmarkPreviewer {
 	/** @var LinkExplorer */
 	protected $linkExplorer;
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
 	/**
-	 * @param FileCache $cache
 	 * @param LinkExplorer $linkExplorer
 	 * @param IClientService $clientService
-	 * @param ILogger $logger
+	 * @param LoggerInterface $logger
 	 */
-	public function __construct(LinkExplorer $linkExplorer, IClientService $clientService, ILogger $logger) {
+	public function __construct(LinkExplorer $linkExplorer, IClientService $clientService, LoggerInterface $logger) {
 		$this->linkExplorer = $linkExplorer;
 		$this->client = $clientService->newClient();
 		$this->logger = $logger;
@@ -74,7 +60,7 @@ class DefaultBookmarkPreviewer implements IBookmarkPreviewer {
 		return null;
 	}
 
-	public function scrapeUrl($url) {
+	public function scrapeUrl($url): array {
 		return $this->linkExplorer->get($url);
 	}
 
@@ -85,8 +71,8 @@ class DefaultBookmarkPreviewer implements IBookmarkPreviewer {
 	protected function fetchImage($url): ?Image {
 		try {
 			$response = $this->client->get($url, ['timeout' => self::HTTP_TIMEOUT]);
-		} catch (\Exception $e) {
-			$this->logger->debug($e, ['app' => 'bookmarks']);
+		} catch (Exception $e) {
+			$this->logger->debug($e->getMessage(), ['app' => 'bookmarks']);
 			return null;
 		}
 		$body = $response->getBody();
